<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
    >
      <el-form-item label="作业区域编码" prop="workareaCode">
        <el-input
          v-model="queryParams.workareaCode"
          placeholder="请输入作业区域编码"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="作业区域名称" prop="workareaName">
        <el-input
          v-model="queryParams.workareaName"
          placeholder="请输入作业区域名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>

      <el-form-item label="状态" prop="status">
        <el-select
          v-model="queryParams.status"
          placeholder="作业区域状态"
          clearable
        >
          <el-option
            v-for="dict in dict.type.sys_normal_disable"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button
          v-no-more-click
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button
          v-no-more-click
          icon="el-icon-refresh"
          size="mini"
          @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          v-no-more-click
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['iscs:workarea:add']"
          >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          v-no-more-click
          type="info"
          plain
          icon="el-icon-sort"
          size="mini"
          @click="toggleExpandAll"
          >展开/折叠
        </el-button>
      </el-col>
      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-table
      v-if="refreshTable"
      v-loading="loading"
      :data="deptList"
      row-key="workareaId"
      :default-expand-all="isExpandAll"
      :tree-props="{ children: 'children', hasChildren: 'hasChildren' }"
    >
      <el-table-column
        prop="workareaCode"
        label="作业区域编码"
        width="260"
      ></el-table-column>
      <el-table-column
        prop="workareaName"
        label="作业区域名称"
        width="260"
      ></el-table-column>
      <el-table-column
        prop="orderNum"
        label="排序"
        width="200"
      ></el-table-column>
      <el-table-column prop="status" label="状态" width="100">
        <template slot-scope="scope">
          <dict-tag
            :options="dict.type.sys_normal_disable"
            :value="scope.row.status"
          />
        </template>
      </el-table-column>
      <el-table-column
        label="作业区域地图"
        align="center"
        prop="create"
        width="200"
      >
        <template slot-scope="scope">
          <el-button
            v-no-more-click
            size="mini"
            type="text"
            @click="look(scope.row)"
            >预览
          </el-button>
        </template>
      </el-table-column>
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
      >
        <template slot-scope="scope">
          <el-button
            v-no-more-click
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['mes:md:waa:edit']"
            >修改
          </el-button>
          <el-button
            v-no-more-click
            size="mini"
            type="text"
            icon="el-icon-plus"
            @click="handleAdd(scope.row)"
            v-hasPermi="['iscs:workarea:add']"
            >新增
          </el-button>

          <el-button
            v-no-more-click
            v-if="scope.row.parentId != 0"
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['mes:md:waa:remove']"
            >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <!-- 添加或修改部门对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="120px">
        <el-row>
          <el-col :span="18">
            <el-form-item label="上级作业区域" prop="parentId">
              <treeselect
                style="width: 318px"
                v-model="form.parentId"
                :options="deptOptions"
                :normalizer="normalizer"
                placeholder="选择上级作业区域"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="18">
            <el-form-item label="作业区域名称" prop="workareaName">
              <el-input
                style="width: 318px"
                v-model="form.workareaName"
                placeholder="请输入区域名称"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="18">
            <el-form-item label="显示排序" prop="orderNum">
              <el-input-number
                style="width: 318px"
                v-model="form.orderNum"
                controls-position="right"
                :min="0"
              />
            </el-form-item>
          </el-col>
        </el-row>

        <el-row>
          <el-col :span="19">
            <el-form-item label="区域编码" prop="workareaCode">
              <el-input
                style="width: 318px"
                v-model="form.workareaCode"
                placeholder="请输入区域编码"
              />
            </el-form-item>
          </el-col>
          <el-col :span="3">
            <el-form-item label-width="80">
              <el-switch
                style="width: 170px"
                v-model="autoGenFlag"
                active-color="#13ce66"
                active-text="自动生成"
                @change="handleAutoGenChange(autoGenFlag)"
              >
              </el-switch>
            </el-form-item>
          </el-col>
        </el-row>
        <el-form-item label="区域状态">
          <el-radio-group v-model="form.status">
            <el-radio :label="'0'">启用</el-radio>
            <el-radio :label="'1'">禁用</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-row>
          <el-col :span="18">
            <el-form-item label="区域地图" prop="mapImg">
              <ImageUploadSingle
                :limit="1"
                :value="form.mapImg"
                :fileSize="5"
                @onUploaded="handleImgUplaoded"
                @onRemoved="handleImgRemoved"
              ></ImageUploadSingle>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="10">
            <el-form-item label="地图json" prop="map">
              <el-input
                style="width: 318px"
                v-model="form.map"
                placeholder="请输入地图json"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="10">
            <el-form-item label="备注" prop="remark">
              <el-input
                type="textarea"
                style="width: 318px"
                v-model="form.remark"
                placeholder="请输入备注"
              />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button v-no-more-click type="primary" @click="submitForm"
          >确 定</el-button
        >
        <el-button v-no-more-click @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listWorkarea,
  getWorkareaInfo,
  addWorkarea,
  updateWorkarea,
  delWorkarea,
  listAllWorkshop,
} from "@/api/mes/wa/workarea";
import Treeselect from "@riophae/vue-treeselect";
import "@riophae/vue-treeselect/dist/vue-treeselect.css";
import { genCode } from "@/api/system/autocode/rule";

export default {
  name: "Dept",
  dicts: ["sys_normal_disable"],
  components: { Treeselect },
  data() {
    return {
      //自动生成编码
      autoGenFlag: false,
      optType: undefined,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      codes: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 地图预览弹框
      dialogVisibleMap: false,
      // 显示搜索条件
      showSearch: true,
      // 表格树数据
      deptList: [],
      // 部门树选项
      deptOptions: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 是否展开，默认全部展开
      isExpandAll: true,
      // 重新渲染表格状态
      refreshTable: true,
      // 查询参数
      queryParams: {
        current: 1,
        size: -1,
        workareaCode: null,
        workareaName: null,
        workareaType: null,
      },
      // 总条数
      total: 0,
      // 表单参数
      form: {
        workshopId: 0,
        parentId: 0,
      },
      WorkShopListOptions: null, //所属车间下拉数据
      EditId: null, //判断是否是编辑弹框的值
      // 表单校验
      rules: {
        // parentId: [
        //   { required: true, message: '父级不能为空', trigger: 'blur' }
        // ],
        orderNum: [
          { required: true, message: "显示排序不能为空", trigger: "blur" },
        ],
        workareaCode: [
          { required: true, message: "区域编号不能为空", trigger: "blur" },
        ],
        workareaName: [
          { required: true, message: "区域名称不能为空", trigger: "blur" },
        ],
        workareaType: [
          { required: true, message: "清选择区域类型", trigger: "blur" },
        ],
      },
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询部门列表 */
    getList() {
      this.loading = true;
      listWorkarea(this.queryParams).then((response) => {
        debugger;
        var depts = this.handleTree(response.data.records, "workareaId");

        this.deptList = depts;
        this.loading = false;
      });
    },
    /** 转换部门数据结构 */
    normalizer(node) {
      if (node.children && !node.children.length) {
        delete node.children;
      }
      return {
        id: node.workareaId,
        label: node.workareaName,
        children: node.children,
      };
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        parentId: undefined,
        orderNum: undefined,
        remark: null,
        map: null,
        workareaCode: null,
        workareaId: undefined,
        workareaName: null,
        workareaType: null,
        workshopId: null,
      };
      this.autoGenFlag = false;
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.current = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.queryParams = {
        current: 1,
        size: -1,
        workareaCode: null,
        workareaName: null,
        workareaType: null,
      };
      this.resetForm("queryForm");
      this.handleQuery();
    },
    /** 新增按钮操作 */
    handleAdd(row) {
      this.reset();
      if (row != undefined) {
        this.form.workshopId = 0;
        this.form.parentId = row.workareaId;
      } else {
        this.form.workshopId = 0;
        this.form.parentId = 0;
      }
      this.open = true;
      this.title = "添加作业区域";
      const data={
        current:1,
        size:-1
      }
      listWorkarea(data).then((response) => {
        this.deptOptions = this.handleTree(
          response.data.records,
          "workareaId"
        );
        console.log(this.deptOptions,'作业区域的树形结构')
      });
    },
    /** 展开/折叠操作 */
    toggleExpandAll() {
      this.refreshTable = false;
      this.isExpandAll = !this.isExpandAll;
      this.$nextTick(() => {
        this.refreshTable = true;
      });
    },
    /** 修改按钮操作 */
    handleUpdate(row) {

      this.EditId = row.workareaId || this.ids;
      getWorkareaInfo(row.workareaId).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改作业区域";
      });
const data={
  current:1,
  size:-1
}
      listWorkarea(data).then((response) => {
        this.deptOptions = this.handleTree(
          response.data.records,
          "workareaId",
          "parentId",
          "children"
        );
      });
    },
    //图片上传成功
    handleImgUplaoded(imgUrl) {
      console.log(imgUrl, "编辑拿到的图片");
      this.form.mapImg = imgUrl[0].url;
    },
    //图片移除
    handleImgRemoved(imgUrl) {
      this.form.mapImg = null;
    },
    /** 提交按钮 */
    submitForm: function () {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.workareaId != undefined) {
            updateWorkarea(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            console.log(this.form, "新增作业区域参数");
            addWorkarea(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      this.$modal
        .confirm('是否确认删除名称为"' + row.workareaCode + '"的数据项？')
        .then(function () {
          return delWorkarea(row.workareaId);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    //自动生成编码
    handleAutoGenChange(autoGenFlag) {
      if (autoGenFlag) {
        genCode("WORKAREA_CODE").then((response) => {
          this.form.workareaCode = response;
        });
      } else {
        this.form.workareaCode = null;
      }
    },
    // 地图预览
    look(row) {
      console.log(row, "row预览");
      const data = row.workareaId;
      this.$router.push(`/mes/md/workarea/index/MapData?workareaId=${data}`);
      // this.dialogVisibleMap = true; // 显示地图预览弹框
    },
  },
};
</script>
